#
# spec file for package saphanabootstrap-formula
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           saphanabootstrap-formula
Version:        0.14.0+git.1699438512.4930943
Release:        1.2
Summary:        SAP HANA platform deployment formula
License:        Apache-2.0

Url:            https://github.com/SUSE/%{name}
Source0:        %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       habootstrap-formula
Requires:       salt-shaptools
%if 0%{?suse_version} < 1500
Recommends:     salt-formulas-configuration
%else
Requires:       salt-formulas-configuration
%endif
Suggests:       prometheus-hanadb_exporter >= 0.7.0

%define fname hana
%define fdir  %{_datadir}/salt-formulas
%define ftemplates templates

%description
SAP HANA deployment salt formula. This formula is capable to install
SAP HANA nodes, enable system replication and configure SLE-HA cluster
with the SAPHanaSR resource agent, using standalone salt or via SUSE Manager
formulas with forms, available on SUSE Manager 4.0.

In order to use the formula, salt must be available in the system. The package comes automatically
in SLE15. To use it in SLE12, salt (and it sub-components) comes from the Advanced systems management
module, which can be added running the `SUSEConnect -p sle-module-adv-systems-management/12/{{ arch }}`

%prep
%setup -q

%build

%install

mkdir -p %{buildroot}%{fdir}/states/%{fname}
mkdir -p %{buildroot}%{fdir}/metadata/%{fname}
cp -R %{fname} %{buildroot}%{fdir}/states
cp -R form.yml pillar.example %{buildroot}%{fdir}/metadata/%{fname}
if [ -f metadata.yml ]
then
  cp -R metadata.yml %{buildroot}%{fdir}/metadata/%{fname}
fi


%files
%defattr(-,root,root,-)
%if 0%{?sle_version} < 120300
%doc README.md LICENSE
%else
%doc README.md
%license LICENSE
%endif

%dir %attr(0755, root, salt) %{fdir}
%dir %attr(0755, root, salt) %{fdir}/states
%dir %attr(0755, root, salt) %{fdir}/metadata

%attr(0755, root, salt) %{fdir}/states/%{fname}
%attr(0755, root, salt) %{fdir}/states/%{fname}/%{ftemplates}
%attr(0755, root, salt) %{fdir}/metadata/%{fname}

%changelog
* Mon Nov  6 2023 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.14.0
  * add susChkSrv HA/DR provider
  * make providers configurable
* Mon Nov  7 2022 Steven Stringer <steven.stringer@suse.com>
- Version bump 0.13.1
  * revert changes to spec file to re-enable SLES RPM builds
* Mon Aug 15 2022 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.13.0
  * pass sid to sudoers in a SLES12 compatible way
  * add location constraint to gcp_stonith
* Thu Aug 11 2022 Christian Schneemann <schneemann@b1-systems.de>
- Version bump 0.12.1
  * moved templates dir into hana dir in repository to be gitfs compatible
* Thu Jul 28 2022 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.12.0
  * add SAPHanaSR takeover blocker
* Tue Jul 19 2022 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.11.0
  * use check_cmd instead of tmp sudoers file
  * make sudoers rules more secure
  * migrate sudoers to template file
* Mon Jun  6 2022 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.10.1
  * fix hook removal conditions
  * fix majority_maker code on case grain is empty
* Fri May 13 2022 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.10.0
  * allow to disable shared HANA basepath and rework add_hosts code
    (enables HANA scale-out on AWS)
  * do not edit global.ini directly (if not needed)
* Thu May  5 2022 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.9.1
  * fix majority_maker code on case grain is empty
* Wed Nov 17 2021 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.9.0
  * define vip_mechanism for every provider and reorder resources
    (same schema for all SAP related formulas)
* Thu Nov 11 2021 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.8.1
  * use multi-target Hook on HANA scale-out
* Thu Jul 29 2021 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.8.0
  * add HANA scale-out support
  * add idempotence to not affect a running HANA and cluster
* Thu Jun 17 2021 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.7.2
  * add native fencing for microsoft-azure
* Wed Jun  9 2021 Eike Waldt <waldt@b1-systems.de>
- fixes a not working import of dbapi in SUSE/ha-sap-terraform-deployments#703
- removes the installation and extraction of all hdbcli files in the /hana/shared/srHook directory
- fixes execution order of srTakeover/srCostOptMemConfig hook
- renames and updates hook srTakeover to srCostOptMemConfig
* Fri May  7 2021 Bernd Schubert <bschubert@suse.com>
- Changing exporter stickiness to => 0 and adjusting the colocation
  score from +inf to -inf and changing the colocation from Master to Slave.
  This change fix the impact of a failed exporter in regards to the HANA DB.
* Thu May  6 2021 Rubén Torrero Marijnissen <rtorreromarijnissen@suse.com>
- Document extra_parameters in pillar.example (bsc#1185643)
* Thu May  6 2021 Xabier Arbulu <xarbulu@suse.com>
- Change hanadb_exporter default timeout value to 30 seconds
* Wed Apr 28 2021 Diego Akechi <dakechi@suse.com>
- Set correct stickiness for the azure-lb resource
  The azure-lb resource receives an stickiness=0 to not influence on
  transitions calculations as the HANA resources have more priority
* Thu Mar 18 2021 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.7.1
- Implement the load balancer use case for GCP in the cluster resource
  agents template
* Fri Mar 12 2021 Xabier Arbulu <xarbulu@suse.com>
- Fix the HANA sidadm usage to transform to lowercase some states
  managing the sudoers file in ha_cluster.sls state file
  (bsc#1185090)
* Fri Mar  5 2021 Xabier Arbulu <xarbulu@suse.com>
- Fix how the HANA client options are handled. Now, if any of the
  HANA client option variables are set, they will have preference
  over the database option (the platform and extracted options)
* Tue Jan 19 2021 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.7.0
  * Change salt-formulas-configuration requirement in SLE12 codestream
  to a recommendation
  (bsc#1177860)
* Wed Dec  2 2020 Simranpal Singh <simranpal.singh@suse.com>
- Start the saptune daemon service
* Tue Nov 24 2020 Simranpal Singh <simranpal.singh@suse.com>
- Add requisite of hana installation to subsequent salt states
* Wed Nov 11 2020 Simranpal Singh <simranpal.singh@suse.com>
- Add support to extract and install HANA Client sar packages
* Mon Oct 19 2020 Xabier Arbulu <xarbulu@suse.com>
- Set the native fence mechanism usage for CSP as optional
* Tue Oct 13 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.6.2:
  * Update the package version after SUMA form update and extraction logic update
  (jsc#SLE-4047)
* Sun Oct 11 2020 Simranpal Singh <simranpal.singh@suse.com>
- Fix the hana media extraction and installation logics when using exe archives
* Thu Oct  8 2020 Simranpal Singh <simranpal.singh@suse.com>
- Update the SUMA hana form metadata, to show hana form under SAP deployment group
* Sat Oct  3 2020 Simranpal Singh <simranpal.singh@suse.com>
- Update SUMA form.yml file and prevalidation state with latest changes in formula
* Thu Sep 24 2020 Simranpal Singh <simranpal.singh@suse.com>
- Change the default 'hana_extract_dir' hana media extraction location
* Tue Sep 22 2020 Dario Maiocchi <dmaiocchi@suse.com>
- Version 0.6.1:
  * Remove copy of config files for exporters since we use /usr/etc
* Thu Aug 20 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.6.0
  * Include pillar example file in package
  (bsc#1174994, jsc#SLE-4047)
* Wed Jul 15 2020 Xabier Arbulu <xarbulu@suse.com>
- Add hana active/active resources to the cluster template
- Change `route_table` by `route_name` to make the variable usage
  more meaningful
* Wed Jun 10 2020 Simranpal Singh <simranpal.singh@suse.com>
- Add support to extract zip,rar,exe,sar hana media
- This change brings non backward compatible changes. The variable
  hdbserver_extract_dir is replaced by hana_extract_dir
* Fri Jun  5 2020 Stefano Torresi <stefano.torresi@suse.com>
- Fix provisioning of hanadb_exporter in SLE12, where python3-pip must be always installed.
* Tue Jun  2 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.5.10
  * Change colocation weight for col_saphana_ip for Azure provider \
  (jsc#ECO-1965, jsc#SLE-4047)
* Fri May 15 2020 Stefano Torresi <stefano.torresi@suse.com>
- Implement exporter Pacemaker resource, refactor monitoring settings
* Fri May 15 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.5.9
  * Update extraction functionality for cost optimized scenario
* Tue Apr 21 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.5.8
  * Adjust software_path usage for cost optimized scenario
* Fri Apr 17 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.5.7
  * Use gcp instance name instead of id in fence_gce agent
  (bsc#1161898, bsc#1160933)
* Tue Apr 14 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.5.6
  * Update anything socat resource by azure-lb as recommended in
  the updated best practices guide
* Tue Mar 31 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.5.5
  * Implement the new SAPHanaSR hook usage
* Fri Mar 27 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.5.4
  * Update the fence_gce usage to use gcp_instance_id
* Wed Mar 25 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.5.3
  * Add support to run sapcar and extract HANA sar package
* Fri Mar 20 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.5.2
  * Install pydbapi package to be used by hanadb_exporter
* Tue Mar  3 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.5.1
  * Adapt the cluster template to use the proper gcp agents
  (bsc#1161898, bsc#1160933)
* Tue Feb 11 2020 Dario Maiocchi <dmaiocchi@suse.com>
- Version 0.5.0
  * Change the package name to prometheus-hanadb_exporter (jsc#SLE-10545)
  (bsc#1165156, jsc#SLE-4143, boo#1137989, jsc#SLE-10545)
* Thu Jan 30 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.4.4
  * Update HANA resources template to add AWS specific RA
* Tue Jan 21 2020 Dario Maiocchi <dmaiocchi@suse.com>
- Version 0.4.3
  * Add saptune module to apply a specific solution
* Thu Jan  2 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.4.2
  * Add the option to specify password XML file for installing hana
* Thu Dec 19 2019 Xabier Arbulu <xarbulu@suse.com>
- Version 0.4.1
  * Update cloud provider usage
* Thu Dec 12 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.4.0
  * Update exporter state to use the new hanadb_exporter config
  folder
  * Clean defaults.yaml file content
  * Fix the scenario where the primary was not defined during
  secondary installation. Now the password can be retrieved using
  other options
  * Update the scale up template to remove the default value for nic
  parameter in the IPaddr2 resource if the provider is not gcp
* Thu Nov 28 2019 Simranpal Singh <simranpal.singh@suse.com>
- Version bump 0.3.3
  * Update Cluster template command to use `socat` for Azure
* Wed Oct 30 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.2
  * Fix issue with file permissions during package installation in
    /usr/share/salt-formulas (0755, root, salt)
    (boo#1142306)
* Tue Oct 29 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.1
  * Fix 'true' rendering in jinja to convert to json correctly
* Fri Oct 25 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.3.0
  * Add support for multi tenant hanadb_exporter
* Wed Sep  4 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Update the pkg.info_available call to avoid repositories refresh as
  it may cause errors
* Wed Aug  7 2019 Simranpal Singh <simranpal.singh@suse.com>
- Version bump 0.2.9
  * Fix srHook script usage for cost optimized scenario
  * Add scenario type options to the form.yml file
    (boo#1137989)
* Wed Jul 31 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Fix errors in the form.yml file to match with the formula names
- Fix some styling issues
* Tue Jul 23 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version bump 0.2.8
  * Add support for Power machines
  * Fix issues with SAP HANA deployment template and the exporter
* Mon Jul 22 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version bump 0.2.7
  * Fix issue with file permissions during package installation in
    /usr/share/salt-formulas
    (boo#1142306)
* Mon Jul  8 2019 Dario Maiocchi <dmaiocchi@suse.com>
- Version bump 0.2.6
  * Retry pkg.install multiple times, in case a pkg installation fails
  for having a more resilient installation.
* Wed Jul  3 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Version bump 0.2.5
  * hanadb_exporter executed as a daemon
  * hanadb_exporter installation suggested
* Tue Jul  2 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Version bump 0.2.4
  * Change the salt-formula directories permissions to 0750 to avoid
    conflicts with the package salt-standalone-formulas-configuration.
  * Correct the required package name to
    salt-standalone-formulas-configuration
* Mon Jul  1 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.3 supporting hanadb_exporter logging system
* Wed Jun 19 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.2 adding hanadb_exporter deployment
* Tue Jun 11 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Create package version 0.2.1 with fixed spec files. Now the package
  is available in all SLE12 and SLE15 versions (boo#1137989, jsc#SLE-4143)
* Thu Jun  6 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Fix how qas instance number is created in scale_up_resources template
* Tue May 21 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Version bump 0.2.0
  * Include the salt-formulas-configuration dependency on
    SLE/Leap 15-SP1 and higher. This package configures the shared salt
    formulas location (/usr/share/salt-formulas) to be used by SUMA 4.0
    or salt in standalone mode.
  * Drops the saphanabootstrap-formula-suma package, as the forms metadata
    will be available only on SUMA 4.0 using the shared location.
* Thu May 16 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Update formula to work with the latest shaptools code. In this version
  the secondary node registration is managed completely in shaptools
* Thu Apr 25 2019 Diego Vinicius Akechi <dakechi@suse.com>
- Changed requires from salt-saphana to salt-shaptools.
* Mon Mar 18 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Update primary available checking to execute this action before
  trying to copy the SSFS files from primary node
- Add configurable timeout to wait to the primary node
* Tue Mar 12 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Fix OS release comparison to use integer type in order to choose
  installable python version
* Fri Mar  8 2019 Xabier Arbulu Insausti <xarbulu@suse.com>
- Improve shaptools installation python version management
* Mon Mar  4 2019 xarbulu@suse.com
- Improved the use of keystore access. When the key_name is informed,
  the user_name/user_password is not needed.
* Mon Feb 25 2019 dakechi@suse.com
- Forces lower case SID when composing the OS username
- Typos fixing.
- Adjust the labels to SAP terminology and include help texts.
* Wed Feb 20 2019 xarbulu@suse.com
- Add templates folder with RA configuration templates
* Thu Dec 20 2018 xarbulu@suse.com
- First version of the SAP HANA deployment formula
